==> rc-ui-lib-2.1.1.tgz: package/es/typography/Typography.js <==
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
import React, { useContext } from "react";
import classnames from "classnames";
import ConfigProviderContext from "../config-provider/ConfigProviderContext";
const TypographyBase = (_a) => {
  var _b = _a, {
    type,
    size = "md",
    level,
    center,
    ellipsis,
    className,
    children,
    strong,
    underline,
    disabled,
    renderType,
    delete: del
  } = _b, props = __objRest(_b, [
    "type",
    "size",
    "level",
    "center",
    "ellipsis",
    "className",
    "children",
    "strong",
    "underline",
    "disabled",
    "renderType",
    "delete"
  ]);
  const {
    prefixCls,
    createNamespace
  } = useContext(ConfigProviderContext);
  const [bem] = createNamespace("typography", prefixCls);
  const elli = ellipsis === true ? 1 : ellipsis;
  return /* @__PURE__ */ React.createElement("div", _extends({
    className: classnames(className, bem([type, size, renderType, {
      center,
      strong,
      underline,
      disabled,
      delete: del,
      [`l${level}`]: renderType === "title" && level
    }]), {
      "rc-ellipsis": elli === 1,
      [`rc-multi-ellipsis--l${elli}`]: elli && elli > 1
    })
  }, props), children);
};
var stdin_default = TypographyBase;
export {
  stdin_default as default
};

==> rc-ui-lib-2.1.3.tgz: package/es/typography/Typography.js <==
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
function _extends() {
  return _extends = Object.assign ? Object.assign.bind() : function(n) {
    for (var e = 1; e < arguments.length; e++) {
      var t = arguments[e];
      for (var r in t)
        ({}).hasOwnProperty.call(t, r) && (n[r] = t[r]);
    }
    return n;
  }, _extends.apply(null, arguments);
}
import React, { useContext } from "react";
import classnames from "classnames";
import ConfigProviderContext from "../config-provider/ConfigProviderContext";
const TypographyBase = (_a) => {
  var _b = _a, {
    type,
    size = "md",
    level,
    center,
    ellipsis,
    className,
    children,
    strong,
    underline,
    disabled,
    renderType,
    delete: del
  } = _b, props = __objRest(_b, [
    "type",
    "size",
    "level",
    "center",
    "ellipsis",
    "className",
    "children",
    "strong",
    "underline",
    "disabled",
    "renderType",
    "delete"
  ]);
  const {
    prefixCls,
    createNamespace
  } = useContext(ConfigProviderContext);
  const [bem] = createNamespace("typography", prefixCls);
  const elli = ellipsis === true ? 1 : ellipsis;
  return /* @__PURE__ */ React.createElement("div", _extends({
    className: classnames(className, bem([type, size, renderType, {
      center,
      strong,
      underline,
      disabled,
      delete: del,
      [`l${level}`]: renderType === "title" && level
    }]), {
      "rc-ellipsis": elli === 1,
      [`rc-multi-ellipsis--l${elli}`]: elli && elli > 1
    })
  }, props), children);
};
var stdin_default = TypographyBase;
export {
  stdin_default as default
};
